<?php

/**
 * @file
 * Contains the admin settings form.
 */

/**
 * FAPI implementation for the admin settings form.
 */
function flir_admin_settings() {
  $form = array();

  // Reset the flir cache
  $fonts = flir_fonts(TRUE);
  $default_path = libraries_get_path('facelift') . '/fonts';

  // Get a list of all themes
  $themes = array();
  foreach (list_themes() as $key => $theme) {
    $themes[$key] = $theme->name;
  }
  $themes = array('all' => 'all') + $themes;

  $form['flush'] = array(
    '#type' => 'submit',
    '#value' => t('Flush FLIR cache'),
    '#submit' => array('flir_flush'),
  );
  
  $form['flir_font_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Font path'),
    '#description' => t('The custom path to your fonts. This should be the relative path from the drupal root.'),
    '#default_value' => variable_get('flir_font_path', $default_path),
  );

  $form['flir_cache_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Font cache path'),
    '#description' => t('The path to the font cache directory. Relative to your sites files directory.'),
    '#default_value' => variable_get('flir_cache_path', 'flir_cache'),
  );

  $form['flir_imagemagick_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to ImageMagick binaries (with trailing slash)'),
    '#description' => t('ImageMagick is only needed by some plugins (e.g. FancyFonts).'),
    '#default_value' => variable_get('flir_imagemagick_path', ''),
  );

  $form['flir_js_file'] = array(
    '#type' => 'select',
    '#title' => t('Select the flir JS file you want to use'),
    '#description' => t("If you're unsure select flir.js."),
    '#default_value' => variable_get('flir_js_file', 'flir.js'),
    '#options' => array(
      'flir.js' => 'flir.js',
      'flirmin.js' => 'flirmin.js',
      'flirlite.js' => 'flirlite.js',
      'flirlitemin.js' => 'flirlitemin.js',
    ),
  );

  $flir_style = variable_get('flir_style', array());
  $form['flir_style'] = array(
    '#type' => 'fieldset',
    '#title' => t('FLIR style settings'),
    '#description' => t('Configure default style settings to apply to all font replacements.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
  );

  $mode_doc = t('Image replacements can be generated usng three separate modes: stretch, progressive, and wrap.');
  $mode_doc .= '<ul>';
  $mode_doc .= '<li>' . t('Stretch will generate an image and resize the HTML element to contain it.') . '</li>';
  $mode_doc .= '<li>' . t('Progressive will shrink the text size of the generated image until it fits inside the HTML elements box.') . '</li>';
  $mode_doc .= '<li>' . t('Wrap will wrap text to fit inside the HTML element') . '</li>';
  $mode_doc .= '</ul>';
    
  $form['flir_style']['mode'] = array(
    '#type' => 'select',
    '#title' => t('Mode'),
    '#description' => $mode_doc,
    '#default_value' => isset($flir_style['mode']) ? $flir_style['mode'] : 'stretch',
    '#options' => array(
      'stretch' => t('Stretch'),
      'progressive' => t('Progressive'),
      'wrap' => t('Wrap'),
    ),
  );

  $form['flir_style']['fancyfonts'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use FancyFonts plugin'),
    '#description' =>  t('This will enable the fancyfonts plugin for all font rendering. See the <a href="http://facelift.mawhorter.net/doc/plugins-fancyfonts">fancyfonts documentation</a> for more details. If this plugin is used only the "wrap" mode setting will be honored, "stretch" and "progressive" will be ignored.. If this setting is modified, the flir caches will automatically be flushed.'),
    '#default_value' => $flir_style['fancyfonts'],
  );

  $flir_replacements = variable_get('flir_replacements', array());
  $form['flir_replacements'] = array(
    '#type' => 'fieldset',
    '#title' => t('Flir replacements'),
    '#tree' => TRUE,
  );

  $count = count($flir_replacements) + 2;
  for ($i = 0; $i < $count; $i++) {
    $replacement = $flir_replacements[$i];

    $form['flir_replacements'][$i] = array(
      '#type' => 'fieldset',
      '#title' => t('Flir replacement ' . ($i + 1)),
      '#collapsible' => FALSE,
    );

    $form['flir_replacements'][$i]['selector'] = array(
      '#type' => 'textfield',
      '#title' => t('Items to replace with Flir generated text'),
      '#default_value' => $replacement['selector'],
      '#description' => t("The CSS selector to replace with a FLIR image."),
    );

    $form['flir_replacements'][$i]['font'] = array(
      '#type' => 'select',
      '#title' => t('Font to use'),
      '#options' => $fonts,
      '#default_value' => !empty($replacement['font']) ? $replacement['font'] : 'default',
      '#description' => t("The font to use for this FLIR replacement."),
    );

    $form['flir_replacements'][$i]['style']['mode'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#description' => t('See description in "Flir style settings" for details'),
      '#default_value' => isset($replacement['style']['mode']) ? $replacement['style']['mode'] : '',
      '#options' => array(
        '' => t('Default'),
        'stretch' => t('Stretch'),
        'progressive' => t('Progressive'),
        'wrap' => t('Wrap'),
      ),
    );
    
    $form['flir_replacements'][$i]['theme'] = array(
      '#type' => 'select',
      '#title' => t('Theme to apply this replacement on'),
      '#description' => t('Select a theme if you wish to apply this replacement to a particular theme'),
      '#options' => $themes,
      '#default_value' => !empty($replacement['theme']) ? $replacement['theme'] : 'all',
    );
  }

  // List out the fonts that currently exist in the system and show a demo
  // of what the rendered version will look like.
  $form['flir_fonts'] = array(
    '#type' => 'fieldset',
    '#title' => t('Font samples'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  foreach ($fonts as $family => $filename) {
    if ($family == 'default') continue;

    $form['flir_fonts'][$family] = array(
      '#type' => 'fieldset',
      '#title' => $filename,
      '#collapsible' => FALSE,
    );

    $class = preg_replace('/[^A-Za-z\-]/', '', $family);
    $form['flir_fonts'][$family]['example'] = array(
      '#value' => $family,
      '#prefix' => '<div style="font-size: 36px !important;" class="' . $class . '">',
      '#suffix' => '</div>',
    );

    flir_replace(".$class", $family);
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * FAPI submit callback for the admin settings form.
 */
function flir_admin_settings_submit($form, &$form_state) {
  $replacements = array();
  foreach ($form_state['values']['flir_replacements'] as $replacement) {
    // Filter out the empty values
    if (!empty($replacement['selector'])) {
      $replacements[] = $replacement;
    }
  }
  variable_set('flir_replacements', $replacements);

  $flir_style = variable_get('flir_style', array());
  if ($flir_style['fancyfonts'] != $form_state['values']['flir_style']['fancyfonts']) {
    // Need to flush the flir cache if the facelift plugin is enabled
    // or disabled.
    flir_flush();
  }
  
  variable_set('flir_style', $form_state['values']['flir_style']);
  variable_set('flir_font_path', $form_state['values']['flir_font_path']);
  variable_set('flir_cache_path', $form_state['values']['flir_cache_path']);
  variable_set('flir_js_file', $form_state['values']['flir_js_file']);
  variable_set('flir_imagemagick_path', $form_state['values']['flir_imagemagick_path']);
}
